KnobsNotifier class
- Inheritance
-
- Implemented types
-
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
all()
→ List<Knob>
-
-
boolean({required String label, String? description, bool initial = false})
→ bool
-
Creates checkbox with
label, description and initial value.
override
-
dispose()
→ void
-
Discards any resources used by the object.
override
-
get<T>(String label)
→ T
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
options<T>({required String label, String? description, required T initial, List<Option<T>> options = const []})
→ T
-
Creates select field with
label, description, initial value and
list of options.
override
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
slider({required String label, String? description, double? initial, double max = 1, double min = 0})
→ double
-
Creates slider knob with
double value.
override
-
sliderInt({required String label, String? description, int? initial, int max = 100, int min = 0, int? divisions})
→ int
-
Creates slider knob with
int value.
override
-
text({required String label, String? description, String initial = ''})
→ String
-
Creates text input field with
label, description and initial value.
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
update<T>(String label, T value)
→ void
-